==> ox-0.4.4.tar.gz: ox-0.4.4/.todo.md <==
- [ ] General bug fixes
  - [ ] Replace command needs to update syntax
  - [ ] Undo / Redo need to be committed more*
  - [ ] Search needs to break beyond what has been loaded into buffer*
  - [ ] Fix multi spaces not registering as tabs*
    - [ ] Find out where tab info goes and how it's used
    - [ ] Show as tabs but be spaces on the backen
  - [ ] Cursor movement improvement
    - [ ] Fully understand the desired behaviour
    - [ ] Where is this activity defined?
    - [ ] Play around with caching original x position and trying to restore it
  - [X] Update bulit-in help message and greeting message
  - [X] Fix status line duplication issues
  - [X] Search and replace needs to stop crashing due to syntax highlighting update
  - [X] Search and replace needs to hide cursor
- [ ] Config and documentation improvement
  - [ ] Look at old ox.ron config - add anything that is missing in new ox
  - [ ] Allow reloading of config file
  - [ ] Include smaller version of config file for example
  - [ ] Update documentation
    - [ ] and readme - show new key bindings i.e. line moving and word deleting
  - [ ] Plugins can feed into status line / greeting message
  - [ ] Edit tab width
  - [ ] More status / greeting message interpolation options
  - [ ] Multiple plug-ins being able to use the same key binding*
- [ ] Safety update
  - [ ] Document backups
  - [ ] Panic busting & nicer panics / errors*
- [ ] Splitting*
  - [ ] Move towards tree structure of document groups
    - [ ] Clean API from in-house Tree struct
  - [ ] Actually render splits on the screen
  - [ ] Split commands / API
  - [ ] Vigorously test resizing / setting window size weirdly
- [ ] Github issue busting
  - [ ] Go through each github issue and implement changes
- [ ] Plugin overhaul
  - [ ] HTML editor*
  - [ ] HTML tag pairs*
  - [ ] Todo lists*
  - [ ] Typing speed measurement
  - [ ] Pomodoro timer
- [ ] Selection, copying, pasting
  - [ ] Mouse interaction 
  - [ ] Wayland clipboard support 
- [ ] Supporting infrastructure
  - [ ] Configuration assistant
  - [ ] Syntax highlighting assistant
  - [ ] Discord rich presence
- [ ] File tree
  - [ ] Implement file tree*
- [ ] Code prettifier
  - [ ] Implement code prettification infrastructure
- [ ] Autocomplete
  - [ ] Implement code autocomplete infrastructure

==> ox-0.4.5.tar.gz: ox-0.4.5/.todo.md <==
- [ ] General bug fixes
  - [ ] Search needs to break beyond what has been loaded into buffer* - 7th
  - [ ] Fix multi spaces not registering as tabs* - 8th
    - [ ] Also investigate the cursor being able to jump out of bounds after a tab character at the end of a line
    - [ ] Find out where tab info goes and how it's used
    - [ ] Show as tabs but be spaces on the backend
  - [ ] Cursor movement improvement - 8th
    - [ ] Fully understand the desired behaviour
    - [ ] Where is this activity defined?
    - [ ] Play around with caching original x position and trying to restore it
  - [X] Update bulit-in help message and greeting message
  - [X] Fix status line duplication issues
  - [X] Search and replace needs to stop crashing due to syntax highlighting update
  - [X] Search and replace needs to hide cursor
  - [X] Replace command needs to update syntax
  - [X] Undo / Redo need to be committed more*
- [ ] Config and documentation improvement
  - [ ] Look at old ox.ron config - add anything that is missing in new ox
  - [ ] Allow reloading of config file
  - [ ] Include smaller version of config file for example
  - [ ] Update documentation
    - [ ] and readme - show new key bindings i.e. line moving and word deleting
  - [ ] Plugins can feed into status line / greeting message
  - [ ] Edit tab width
  - [ ] More status / greeting message interpolation options
  - [ ] Multiple plug-ins being able to use the same key binding*
- [ ] General tweaks
  - [ ] Group events together when committing for undo/redo
- [ ] Safety update
  - [ ] Document backups
  - [ ] Panic busting & nicer panics / errors*
- [ ] Splitting*
  - [ ] Move towards tree structure of document groups
    - [ ] Clean API from in-house Tree struct
  - [ ] Actually render splits on the screen
  - [ ] Split commands / API
  - [ ] Vigorously test resizing / setting window size weirdly
- [ ] Github issue busting
  - [ ] Go through each github issue and implement changes
- [ ] Plugin overhaul
  - [ ] HTML editor*
  - [ ] HTML tag pairs*
  - [ ] Todo lists*
  - [ ] Typing speed measurement
  - [ ] Pomodoro timer
- [ ] Selection, copying, pasting
  - [ ] Mouse interaction 
  - [ ] Wayland clipboard support 
- [ ] Supporting infrastructure
  - [ ] Configuration assistant
  - [ ] Syntax highlighting assistant
  - [ ] Discord rich presence
- [ ] File tree
  - [ ] Implement file tree*
- [ ] Code prettifier
  - [ ] Implement code prettification infrastructure
- [ ] Autocomplete
  - [ ] Implement code autocomplete infrastructure
